@@ -69,7 +69,7 @@ static int xbm_encode_frame(AVCodecContext *avctx, AVPacket *pkt,
 
 static av_cold int xbm_encode_close(AVCodecContext *avctx)
 {
-    av_freep(&avctx->coded_frame);
+    av_frame_free(&avctx->coded_frame);
 
     return 0;
 }
